#
# spec file for package kubearmor-client
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kubearmor-client
Version:        1.2.1
Release:        1.1
Summary:        KubeArmor cli tool aka kArmor
License:        Apache-2.0
URL:            https://github.com/kubearmor/kubearmor-client
Source:         kubearmor-client-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
karmor is a client tool to help manage KubeArmor, which is a Cloud-native
Runtime Security Enforcement System. Workload hardening and implementing
least-permissive policies made easy.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%setup -q
%setup -q -T -D -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-s -w \
   -X github.com/kubearmor/kubearmor-client/selfupdate.GitCommit=v%{version} \
   -X github.com/kubearmor/kubearmor-client/selfupdate.GitSummary=v%{version} \
   -X github.com/kubearmor/kubearmor-client/selfupdate.GitBranch=main  \
   -X github.com/kubearmor/kubearmor-client/selfupdate.GitState=clean  \
   -X github.com/kubearmor/kubearmor-client/selfupdate.BuildDate=${BUILD_DATE}" \
   -o bin/kubearmor-client .

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"
cd "%{buildroot}/%{_bindir}/"
ln -s %{name} karmor

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/karmor

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Sat Mar 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.2.1:
  * fixed stdout issue with log message
  * update tls config
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- BuildRequire go1.22 following upstream
- Update to version 1.2.0:
  * add mtls support
  * chore: use go toolchain 1.22.1
  * chore(ci): upgrade codeqql to v3
  * Added operator CR updation functionality
  * linted readme
  * Enabled operator installation for karmor
  * Fixed the probe panic issue
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.1.1:
  * fix bug & add flags
  * feat(deps):Updated codeQL to v2
  * update kubearmor protobuf
  * updated karmor install with relay's sa and rbac policies
* Thu Feb  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.1.0:
  * enable custom registry
* Mon Dec  4 2023 kastl@b1-systems.de
- Update to version 1.0.0:
  * updated kubearmor dependencies
  * ignore cluster access with save flag
* Fri Nov 17 2023 kastl@b1-systems.de
- Update to version 0.14.3:
  * update go version to v1.21
  * fix `karmor uninstall`
  * fixing the issue about progress bar
  * default read permissions for all workflows
- BuildRequire go1.21
* Wed Oct 25 2023 kastl@b1-systems.de
- Update to version 0.14.2:
  * fix(deps): update github.com/kubearmor/kubearmor/deployments
    digest to 15ad34e
  * feat: allow karmor probe to show policies applied in systemd
    mode
  * remove summary, discover as they depend on an external tool
  * add govulncheck install check
  * add govulncheck scan to Makefile
* Wed Oct 11 2023 Johannes Kastl <kastl@b1-systems.de>
- upstream fixed the missing third digit in the version, code stays
  the same (tag 0.14 has the same code as 0.14.1)
* Tue Oct 10 2023 kastl@b1-systems.de
- Update to version 0.14:
  * feat(ns): update default namespace to "kubearmor" (#361)
  * feat: Add support for k0s
  * feat: Enhanced handling of policy addition and deletion events
  * Add license scan report and status
  * handling comments and empty objects in policy
  * migrate Userhome func to common
  * refractoring recommend cli
* Mon Oct  9 2023 Johannes Kastl <kastl@b1-systems.de>
- new package kubearmor-client: CLI for the Kubernetes KubeArmor
  Cloud-native Runtime Security Enforcement System
